@@ -82,11 +82,6 @@
 -define(IS_WHITESPACE(C),
         (C =:= $\s orelse C =:= $\t orelse C =:= $\r orelse C =:= $\n)).
 
--ifdef(map_unavailable).
--define(IS_MAP(_), false).
--else.
--define(IS_MAP(X), is_map(X)).
--endif.
 
 %% @type json_string() = atom | binary()
 %% @type json_number() = integer() | float()
@@ -159,14 +154,8 @@ parse_decoder_options([{format, Format} | Rest], State)
   when Format =:= struct orelse Format =:= eep18 orelse Format =:= proplist ->
     parse_decoder_options(Rest, State#decoder{object_hook=Format}).
 
--ifdef(map_unavailable).
-make_object_hook_for_map() ->
-    exit({json_decode, {bad_format, map_unavailable}}).
--else.
 make_object_hook_for_map() ->
     fun ({struct, P}) -> maps:from_list(P) end.
--endif.
-
 
 json_encode(true, _State) ->
     <<"true">>;
@@ -194,7 +183,7 @@ json_encode(Array, State) when is_list(Array) ->
     json_encode_array(Array, State);
 json_encode({array, Array}, State) when is_list(Array) ->
     json_encode_array(Array, State);
-json_encode(M, State) when ?IS_MAP(M) ->
+json_encode(M, State) when is_map(M) ->
     json_encode_map(M, State);
 json_encode({json, IoList}, _State) ->
     IoList;
@@ -223,11 +212,6 @@ json_encode_proplist(Props, State) ->
     [$, | Acc1] = lists:foldl(F, "{", Props),
     lists:reverse([$\} | Acc1]).
 
--ifdef(map_unavailable).
-json_encode_map(Bad, _State) ->
-  %% IS_MAP definition guarantees that this branch is dead
-  exit({json_encode, {bad_term, Bad}}).
--else.
 json_encode_map(Map, _State) when map_size(Map) =:= 0 ->
     <<"{}">>;
 json_encode_map(Map, State) ->
@@ -238,7 +222,6 @@ json_encode_map(Map, State) ->
           end,
     [$, | Acc1] = maps:fold(F, "{", Map),
     lists:reverse([$\} | Acc1]).
--endif.
 
 json_encode_string(A, State) when is_atom(A) ->
     json_encode_string(atom_to_binary(A, latin1), State);
@@ -977,8 +960,6 @@ utf8_non_character_test_() ->
     [{"roundtrip escaped", ?_assertEqual(S, decode(encode(S)))},
      {"roundtrip utf8", ?_assertEqual(S, decode((encoder([{utf8, true}]))(S)))}].
 
--ifndef(map_unavailable).
-
 decode_map_test() ->
     Json = "{\"var1\": 3, \"var2\": {\"var3\": 7}}",
     M = #{<<"var1">> => 3,<<"var2">> => #{<<"var3">> => 7}},
@@ -992,5 +973,3 @@ encode_empty_map_test() ->
     ?assertEqual(<<"{}">>, encode(#{})).
 
 -endif.
-
--endif.
