@@ -540,7 +540,7 @@ extract_q(KVRe, QRe, [Param | Rest], Acc) ->
 %%
 %%      The returned list of encodings is sorted, descendingly, according to the
 %%      Q values of the given list. The last element of this list is the given
-%%      default encoding unless this encoding is explicitily or implicitily
+%%      default encoding unless this encoding is explicitly or implicitily
 %%      marked with a Q value of 0.0 in the given Q values list.
 %%      Note: encodings with the same Q value are kept in the same order as
 %%            found in the input Q values list.
@@ -627,13 +627,8 @@ normalize_path("/" ++ Path, "/" ++ _ = Acc) ->
 normalize_path([C|Path], Acc) ->
         normalize_path(Path, [C|Acc]).
 
--ifdef(rand_mod_unavailable).
-rand_uniform(Start, End) ->
-    crypto:rand_uniform(Start, End).
--else.
 rand_uniform(Start, End) ->
     Start + rand:uniform(End - Start) - 1.
--endif.
 
 %%
 %% Tests
