@@ -1,12 +1,17 @@
 -module(mochiweb_test_util).
 -export([with_server/3, client_request/4, sock_fun/2,
-         read_server_headers/1, drain_reply/3]).
+         read_server_headers/1, drain_reply/3, ssl_client_opts/1]).
 -include("mochiweb_test_util.hrl").
 -include_lib("eunit/include/eunit.hrl").
 
 ssl_cert_opts() ->
-    EbinDir = filename:dirname(code:which(?MODULE)),
-    CertDir = filename:join([EbinDir, "..", "support", "test-materials"]),
+    {ok, Cwd} = file:get_cwd(),
+    CertDir = filename:join(
+        case filename:basename(Cwd) of
+            %% rebar2 compatibility
+            ".eunit" -> [".."];
+            _ -> []
+        end ++ ["support", "test-materials"]),
     CertFile = filename:join(CertDir, "test_ssl_cert.pem"),
     KeyFile = filename:join(CertDir, "test_ssl_key.pem"),
     [{certfile, CertFile}, {keyfile, KeyFile}].
@@ -25,6 +30,9 @@ with_server(Transport, ServerFun, ClientFun) ->
     mochiweb_http:stop(Server),
     Res.
 
+ssl_client_opts(Opts) ->
+  [{server_name_indication, disable} | Opts].
+
 sock_fun(Transport, Port) ->
     Opts = [binary, {active, false}, {packet, http}],
     case Transport of
@@ -42,7 +50,7 @@ sock_fun(Transport, Port) ->
                     Socket
             end;
         ssl ->
-            {ok, Socket} = ssl:connect("127.0.0.1", Port, [{ssl_imp, new} | Opts]),
+            {ok, Socket} = ssl:connect("127.0.0.1", Port, ssl_client_opts(Opts)),
             fun (recv) ->
                     ssl:recv(Socket, 0);
                 ({recv, Length}) ->
@@ -59,6 +67,11 @@ sock_fun(Transport, Port) ->
 client_request(Transport, Port, Method, TestReqs) ->
     client_request(sock_fun(Transport, Port), Method, TestReqs).
 
+body({ chunked, ChunkedBody }) ->
+    ChunkedBody;
+body(Body) ->
+    Body.
+
 client_request(SockFun, _Method, []) ->
     {the_end, {error, closed}} = {the_end, SockFun(recv)},
     ok;
@@ -67,7 +80,7 @@ client_request(SockFun, Method,
     Request = [atom_to_list(Method), " ", Path, " HTTP/1.1\r\n",
                client_headers(Body, Rest =:= []),
                "\r\n",
-               Body],
+               body(Body)],
     ok = SockFun({setopts, [{packet, http}]}),
     ok = SockFun({send, Request}),
     case Method of
@@ -110,14 +123,20 @@ read_server_headers(SockFun, Headers) ->
               mochiweb_headers:insert(Header, Value, Headers))
     end.
 
+body_length_headers(<<>>) ->
+    "";
+body_length_headers({ chunked, _ }) ->
+    "Transfer-Encoding: chunked\r\n";
+body_length_headers(Body) ->
+    ["Content-Length: ", integer_to_list(byte_size(Body)), "\r\n"].
+
 client_headers(Body, IsLastRequest) ->
     ["Host: localhost\r\n",
      case Body of
         <<>> ->
             "";
         _ ->
-            ["Content-Type: application/octet-stream\r\n",
-             "Content-Length: ", integer_to_list(byte_size(Body)), "\r\n"]
+            ["Content-Type: application/octet-stream\r\n" | body_length_headers(Body)]
      end,
      case IsLastRequest of
          true ->
